%	Evaluation of frequency-dependent per-unit-length inductance and resistance of 
%	microstrip transmission lines using closed-form formulas from
%	A. R. Djordjevic, M. Stojilovic, and T. K. Sarkar, "Closed-form formulas for 
%	frequency-dependent per-unit-length inductance and resistance of microstrip transmission lines 
%	that provide causal response",
% IEEE Transactions on Electromagnetic Compatibility, Vol. 56, No. 6, December 2014, pp. 1604-1612.

w = str2num(w_string) * 1e-3;           % conversion from mm to m
h = str2num(h_string) * 1e-3;           % conversion from mm to m
g = str2num(g_string) * 1e-3;           % conversion from mm to m
t = str2num(t_string) * 1e-6;           % conversion from um to m
fstart = str2num(fstart_string) * 1e9;  % conversion from GHz to Hz
fstop = str2num(fstop_string) * 1e9;    % conversion from GHz to Hz
sigma = str2num(sigma_string) * 1e6;    % conversion from MS/m to S/m
nf = str2num(nf_string);


%	test input data

%	test physical limitations
%	strip width must be positive
if w<=0
	fprintf('Input data error! Test failed for w>0: w=%e mm \n',w*1e3)
	return
end
%	substrate thickness must be positive
if h<=0
	fprintf('Input data error! Test failed for h>0: h=%e mm \n',h*1e3)
	return
end
%	metallization thickness must be positive
if t<=0
	fprintf('Input data error! Test failed for t>0: t=%e um \n',t*1e6)
	return
end

%	conductivity must be positive
if sigma<=0
	fprintf('Input data error! Test failed for sigma>0: sigma=%e MS/m \n',sigma/1e6)
	return
end

%	start frequency must be positive
if fstart<=0
	fprintf('Input data error! Test failed for fstart>0: fstart=%e Hz \n',fstart)
	return
end
%	stop frequency must be greater than start frequency
if fstop<=fstart
	fprintf('Input data error! Test failed for fstop>fstart: fstop=%e Hz \n',fstop)
	return
end
%	number frequencies must be greater than 1
if nf<=1
	fprintf('Input data error! Test failed for nf>1: nf=%e \n',nf)
	return
end

%	test if the ground conductor is wider than the strip
if g<w
	fprintf('Input data error! Test failed for g>=w: g=%e mm \n',g*1e3)
	return
end

%	test limitations from the IEEE-TEMC paper
if (w/h<1/4)||(w/h>8)
	fprintf('Input data error! Test failed for 1/4<=w/h<=8: w/h=%e \n',w/h)
	return
end
tempm=max(w/h,1);
if (g/h<tempm)||(g/h>128)	%	note that the first inequality is automatically satistfied if the ground plane is wide enough
	fprintf('Input data error! Test failed for max(w/h,1)<=g/h<=128: w/h=%e, g/h=%e \n',w/h,g/h)
	return
end
tempm=min(w/h,1);
if (t/h<1/128)||(t/h>tempm)
	fprintf('Input data error! Test failed for 1/128<=t/h<=min(w/h,1): w/h=%e, t/h=%e \n',w/h,t/h)
	return
end

if strcmp(f_scale, 'Logarithmic')
    df=nthroot(fstop/fstart,nf-1);
    frequ=power(df, (1:nf) - 1)*fstart;
else
    df=(fstop-fstart)/(nf-1);
    frequ=(1:nf)*df-df+fstart;
end

Microstrip_l_r_kernel

figure(1)
if strcmp(f_scale, 'Logarithmic')
    semilogx(frequ,lpul*1e9,'b','LineWidth',2)
else
    plot(frequ,lpul*1e9,'b','LineWidth',2)
end
xlabel('f [Hz]')
ylabel('L'' [nH/m]')
grid on
print('-f1','Lpul','-dpng')

figure(2)
if strcmp(f_scale, 'Logarithmic')
    semilogx(frequ,rpul,'b','LineWidth',2)
else
    plot(frequ,rpul,'b','LineWidth',2)
end
xlabel('f [Hz]')
ylabel('R'' [Ohm/m]')
grid on
print('-f2','Rpul','-dpng')