% Closed-formula interpolation for frequency dependent R' and L' of micorstrip lines (causal formula) from
%	A. R. Djordjevic, M. Stojilovic, and T. K. Sarkar, "Closed-form formulas for 
%	frequency-dependent per-unit-length inductance and resistance of microstrip transmission lines 
%	that provide causal response",
% IEEE Transactions on Electromagnetic Compatibility, Vol. 56, No. 6, December 2014, pp. 1604-1612.

%   Notation as in manuscript
%   Differences with respect to the manuscript:
%   Corrected a misprint in equation (3); d replaced by h

%   Input data:
%   h - substrate thickness
%   g - ground-plane width
%   w - strip width
%   t - metallization thickness
%   sigma - conductivity
%   frequ() - frequencies
%   nf - number of frequencies

%   Output data:
%   fskin - normalizing frequency
%   wskin - normalizing angular frequency
%   rpul - p.u.l. resistance
%   lpul - p.u.l. inductance


%	get Linpar result at finf

mu=4e-7*pi;
a=w/2;
b=g/2;
d=t/2;

fskin=1/(pi*mu*sigma*t^2);	% normalizing frequency
wskin=2*pi*fskin;
finf=100*fskin;	% reference frequency for Linpar
winf=2*pi*finf;

filew='config.dat';
fidw=fopen(filew,'w');
fprintf(fidw,'%e \n',0);
fprintf(fidw,'%e \n',finf);
fprintf(fidw,'%e \n',sigma);
fclose(fidw);

nwt=10;
ngt=nwt;
ng=round(ngt*g/t);
if ng>300
	ng=300;
end
nw=round(nwt*w/t);
if nw>50
	nw=50;
end

filew='temp.in';
fidw=fopen(filew,'w');
fprintf(fidw,'%e \n',g);
fprintf(fidw,'%e \n',h);
fprintf(fidw,'%e \n',w);
fprintf(fidw,'%e \n',t);
fprintf(fidw,'%e \n',t);
fprintf(fidw,'%i \n',ng);
fprintf(fidw,'%i \n',nw);
fprintf(fidw,'%i \n',ngt);
fprintf(fidw,'%i \n',nwt);
fclose(fidw);

system ('MS.exe');

filer='matout.dat';
fidr=fopen(filer,'r');
linf=fscanf(fidr,'%e /n');
c=fscanf(fidr,'%e /n');
rinf=fscanf(fidr,'%e /n');
fclose(fidr);

%	evaluate d.c. inductance

l0=-2.5e-8*(fintsd(a,d)/a^2+fintsd(b,d)/b^2-(fintmd(a,b,d,h+3*d)-fintmd(a,b,d,h+d))/(a*b))/(t^2);	%	not reliable when h>>w,g,t

%	evaluate d.c. resistances

ra0=1/(sigma*w*t);
rb0=1/(sigma*g*t);
r0=ra0+rb0;
r0p=ra0*rb0/(ra0+rb0);


gl=log(g/h)/log(2);
tl=log(t/h)/log(2);
wl=log(0.1+w/h)/log(2);

					ff0=2.4+0.12*log(1+w/h)+0.1*log(1+g/h)...
	;
					p1=0.14*(pi/2+atan(gl-6.-0.2*wl^2))+0.2*(pi/2-atan(10*(gl-2.8-0.15*wl)))...
	;
					q=5.8...
	;
					r=8+1.8*gl/(1+60*t/h)+0.00045*(g/h)^2*(0.5*h/w/(1+0.5*h/w))+3/(1+w/h)...
	;
					p2=1/(1+(w/h)^2+(gl-1.5)^2)+0.3e-6*(g/h)^2-0.01...
	;
					a=0.8+0.48*log(1+100*t/h)*log(1+8*(h/w))+0.6*(t/w)^2*(1+h/w)-0.24*tl/(1+0.125*w/h)-0.24*(gl-5)+0.002*g/h...
	;
					b=0.3*log(1+200*t/h)...
	;

f0=ff0*r0p/mu;	% upper limit of low-frequency region; localization of the first rational term
w0=2*pi*f0;
f1=q*f0;	% localization of the second rational term
w1=2*pi*f1;
w2=r*r0/l0;
f2=w2/(2*pi);   % localization of the third rational term

f3=a/(pi*mu*sigma*t^2);   % localization of the square-root term
w3=2*pi*f3;
alpha=sqrt(w3/winf);

lcorr=rinf*2/winf/(alpha+sqrt(alpha^2*b));

ldiff=l0-linf-lcorr;

lpul=zeros(1,nf);
rpul=zeros(1,nf);

for i=1:nf
	f=frequ(i);

	wi=2*pi*f;
	s=1i*wi;

	zpul=s*linf ...
		...
		+ s*ldiff*...
        ((1-p2)*((1-p1)/(1+s/w0) ...
        +            p1/(1+s/w1)) ...
		+            p2/(1+s/w2)) ...
		...
		+ r0...
		...
		+ rinf*sqrt(w3/winf)*2*s/w3/(1+sqrt(b+2*s/w3)) ...
        ;

	rpul(i)=real(zpul);
	lpul(i)=imag(zpul)/wi;

end